@@ -1,5 +1,3 @@
-package org.apache.maven.shared.dependency.analyzer;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.dependency.analyzer;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.dependency.analyzer;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.dependency.analyzer;
 
 import java.io.IOException;
 import java.net.URL;
@@ -28,8 +27,7 @@ import java.util.Set;
  *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
  */
-public interface ClassAnalyzer
-{
+public interface ClassAnalyzer {
 
     /**
      * <p>analyze.</p>
@@ -38,6 +36,16 @@ public interface ClassAnalyzer
      * @return a {@link java.util.Set} object
      * @throws java.io.IOException if any
      */
-    Set<String> analyze( URL url )
-        throws IOException;
+    default Set<String> analyze(URL url) throws IOException {
+        return analyze(url, new ClassesPatterns());
+    }
+
+    /**
+     * <p>analyze.</p>
+     *
+     * @param url the JAR file or directory to analyze
+     * @return a {@link java.util.Set} object
+     * @throws java.io.IOException if any
+     */
+    Set<String> analyze(URL url, ClassesPatterns excludedClasses) throws IOException;
 }
