@@ -1,5 +1,3 @@
-package org.apache.maven.shared.dependency.analyzer;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.dependency.analyzer;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.dependency.analyzer;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.dependency.analyzer;
 
 import java.io.InputStream;
 import java.util.HashSet;
@@ -29,26 +28,29 @@ import java.util.Set;
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
  * @see #getClasses()
  */
-public class CollectorClassFileVisitor
-    implements ClassFileVisitor
-{
+public class CollectorClassFileVisitor implements ClassFileVisitor {
     private final Set<String> classes;
 
+    private final ClassesPatterns excludedClasses;
+
     /**
      * <p>Constructor for CollectorClassFileVisitor.</p>
      */
-    public CollectorClassFileVisitor()
-    {
+    public CollectorClassFileVisitor() {
+        this(new ClassesPatterns());
+    }
+
+    public CollectorClassFileVisitor(ClassesPatterns excludedClasses) {
         classes = new HashSet<>();
+        this.excludedClasses = excludedClasses;
     }
 
     /** {@inheritDoc} */
-    public void visitClass( String className, InputStream in )
-    {
+    @Override
+    public void visitClass(String className, InputStream in) {
         // inner classes have equivalent compilation requirement as container class
-        if ( className.indexOf( '$' ) < 0 )
-        {
-            classes.add( className );
+        if (className.indexOf('$') < 0 && !excludedClasses.isMatch(className)) {
+            classes.add(className);
         }
     }
 
@@ -57,8 +59,7 @@ public class CollectorClassFileVisitor
      *
      * @return a {@link java.util.Set} object.
      */
-    public Set<String> getClasses()
-    {
+    public Set<String> getClasses() {
         return classes;
     }
 }
